'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('./_virtual/_rollupPluginBabelHelpers.cjs');
var InterfaceImplementationMissingError = require('./errors/InterfaceImplementationMissingError.cjs');

exports.Endian = void 0;

/**
 * Represents all the size options for array-like serializers
 * — i.e. `array`, `map` and `set`.
 *
 * It can be one of the following:
 * - a {@link NumberSerializer} that prefixes its content with its size.
 * - a fixed number of items.
 * - or `'remainder'` to infer the number of items by dividing
 *   the rest of the buffer by the fixed size of its item.
 *   Note that this option is only available for fixed-size items.
 */
(function (Endian) {
  Endian["Little"] = "le";
  Endian["Big"] = "be";
})(exports.Endian || (exports.Endian = {}));
class NullSerializer {
  constructor() {
    _rollupPluginBabelHelpers.defineProperty(this, "error", new InterfaceImplementationMissingError.InterfaceImplementationMissingError('SerializerInterface', 'serializer'));
  }
  tuple() {
    throw this.error;
  }
  array() {
    throw this.error;
  }
  map() {
    throw this.error;
  }
  set() {
    throw this.error;
  }
  option() {
    throw this.error;
  }
  nullable() {
    throw this.error;
  }
  struct() {
    throw this.error;
  }
  enum() {
    throw this.error;
  }
  dataEnum() {
    throw this.error;
  }
  string() {
    throw this.error;
  }
  bool() {
    throw this.error;
  }
  unit() {
    throw this.error;
  }
  u8() {
    throw this.error;
  }
  u16() {
    throw this.error;
  }
  u32() {
    throw this.error;
  }
  u64() {
    throw this.error;
  }
  u128() {
    throw this.error;
  }
  i8() {
    throw this.error;
  }
  i16() {
    throw this.error;
  }
  i32() {
    throw this.error;
  }
  i64() {
    throw this.error;
  }
  i128() {
    throw this.error;
  }
  f32() {
    throw this.error;
  }
  f64() {
    throw this.error;
  }
  bytes() {
    throw this.error;
  }
  publicKey() {
    throw this.error;
  }
}

exports.NullSerializer = NullSerializer;
//# sourceMappingURL=SerializerInterface.cjs.map
