import { generateSigner, createSignerFromKeypair } from './Keypair.mjs';

const signerIdentity = (signer, setPayer = true) => ({
  install(umi) {
    umi.identity = signer;
    if (setPayer) {
      umi.payer = signer;
    }
  }
});
const signerPayer = signer => ({
  install(umi) {
    umi.payer = signer;
  }
});
const generatedSignerIdentity = (setPayer = true) => ({
  install(umi) {
    const signer = generateSigner(umi);
    umi.use(signerIdentity(signer, setPayer));
  }
});
const generatedSignerPayer = () => ({
  install(umi) {
    const signer = generateSigner(umi);
    umi.use(signerPayer(signer));
  }
});
const keypairIdentity = (keypair, setPayer = true) => ({
  install(umi) {
    const signer = createSignerFromKeypair(umi, keypair);
    umi.use(signerIdentity(signer, setPayer));
  }
});
const keypairPayer = keypair => ({
  install(umi) {
    const signer = createSignerFromKeypair(umi, keypair);
    umi.use(signerPayer(signer));
  }
});

export { generatedSignerIdentity, generatedSignerPayer, keypairIdentity, keypairPayer, signerIdentity, signerPayer };
//# sourceMappingURL=SignerPlugins.mjs.map
